#include <cassert>
#include <cmath>
#include <cstdio>
#include <cstdlib>
#include <cstring>

#define TASKNAME "lnp"

const int MaxN = 10, MaxP = (MaxN * (MaxN - 1)) >> 1,
 MaxL = (MaxP * (MaxP - 1)) >> 1;
typedef int point [3];

point a [MaxN], p [MaxP], b [MaxL];
int x [MaxN], y [MaxN];
int n, k, l;

template <class T> T sqr (T x) {return x * x;}

bool construct (point & p, const point & a, const point & b)
{
 p[0] = a[1] * b[2] - a[2] * b[1];
 p[1] = a[2] * b[0] - a[0] * b[2];
 p[2] = a[0] * b[1] - a[1] * b[0];
 return sqr (p[0]) + sqr (p[1]) + sqr (p[2]);
}

bool is_finite_line (const point & p)
{
 return sqr (p[1]) + sqr (p[2]);
}

bool is_finite_point (const point & p)
{
 return sqr (p[0]);
}

bool incident (const point & a, const point & p)
{
 return !(a[0] * p[0] + a[1] * p[1] + a[2] * p[2]);
}

int main (void)
{
 point f, r;
 int i, j, m;
 int cur, res;
 freopen (TASKNAME ".in", "rt", stdin);
 freopen (TASKNAME ".out", "wt", stdout);
 while (scanf (" %d", &n) != EOF)
 {
  assert (n >= 1 && n <= 10);
  for (i = 0; i < n; i++)
  {
   scanf (" %d %d", &x[i], &y[i]);
   assert (x[i] >= -10 && x[i] <= 10);
   assert (y[i] >= -10 && y[i] <= 10);
   a[i][0] = 1;
   a[i][1] = x[i];
   a[i][2] = y[i];
  }
  k = 0;
  for (i = 0; i < n - 1; i++)
   for (j = i + 1; j < n; j++)
    if (construct (p[k], a[i], a[j]) && is_finite_line (p[k]))
     k++;
  l = 0;
  for (i = 0; i < k - 1; i++)
   for (j = i + 1; j < k; j++)
    if (construct (b[l], p[i], p[j]) && is_finite_point (b[l]))
     l++;
//  printf ("The level sizes are: %d %d %d\n", n, k, l);
  res = 0;
  memmove (f, a[0], sizeof (f));
  f[1]++;
  if (!construct (r, a[0], f) || !is_finite_line (r)) assert (false);
  for (i = 0; i < n; i++)
   for (j = 0; j < l; j++)
    if (construct (f, a[i], b[j]) && is_finite_line (f))
    {
     cur = 0;
     for (m = 0; m < l; m++)
      cur += incident (f, b[m]);
     if (res < cur)
     {
      res = cur;
      memmove (r, f, sizeof (r));
     }
    }
  printf ("%d\n", res);
  printf ("%d %d %d\n", r[1], r[2], r[0]);
 }
 return 0;
}
