#include <cassert>
#include <cmath>
#include <cstdio>
#include <cstdlib>
#include <cstring>

#define TASKNAME "convex"

enum {OK, WA, PE, JE, NUM};
const char err [NUM] [4] = {"OK", "WA", "PE", "JE"};

FILE * fin, * fout;

void chkexit (const char * msg, int code)
{
 fprintf (stderr, "%s: %s\n", err[code], msg);
 exit (code);
}

void chkend (FILE * f, int mask)
{
 char ch;
 if (fscanf (f, " %c", &ch) == 1)
  chkexit ("Extra information given!", PE | mask);
}

const int MinN = 3, MaxN = 100, MaxC = 1000;

int x [MaxN], y [MaxN];
int xh [MaxN + 1], yh [MaxN + 1];
bool b [MaxN];
int n, k;

int sp (int x0, int y0, int x1, int y1, int x2, int y2)
{
 return (x1 - x0) * (x2 - x0) + (y1 - y0) * (y2 - y0);
}

int vp (int x0, int y0, int x1, int y1, int x2, int y2)
{
 return (x1 - x0) * (y2 - y0) - (x2 - x0) * (y1 - y0);
}

bool answer (FILE * f, int mask)
{
 int i, j, s, t;

 if (fscanf (f, " %d", &k) != 1)
  chkexit ("No k given!", PE | mask);
 memset (b, 0, sizeof (b));
 for (i = 0; i < k; i++)
 {
  if (fscanf (f, " %d %d", &xh[i], &yh[i]) != 2)
   chkexit ("No x or y given!", WA | mask);
  for (j = 0; j < n; j++)
   if (xh[i] == x[j] && yh[i] == y[j])
    break;
  if (j == n)
   chkexit ("No such point!", WA | mask);
  if (b[j])
   chkexit ("Point used twice!", WA | mask);
  b[j] = true;
 }
 chkend (f, mask);

 xh[k] = xh[0];
 yh[k] = yh[0];
 for (i = 0; i < k; i++)
  for (j = 0; j < n; j++)
  {
   s = vp (xh[i], yh[i], xh[i + 1], yh[i + 1], x[j], y[j]);
   if (s > 0) return false;
   else if (s == 0)
   {
    t = vp (x[j], y[j], xh[i], yh[i], xh[i + 1], yh[i + 1]);
    if (t > 0) return false;
   }
  }
 return true;
}

int main (int argc, char * argv [])
{
 int i;
 bool rc;
 assert (argc >= 3);
 if ((fin = fopen (argv[1], "r")) == NULL) chkexit ("No input file!", JE);
 if ((fout = fopen (argv[2], "r")) == NULL) chkexit ("No output file!", PE);
 if (fscanf (fin, " %d", &n) != 1)
  chkexit ("No n in test!", JE);
 assert (n >= MinN && n <= MaxN);
 for (i = 0; i < n; i++)
 {
  if (fscanf (fin, " %d %d", &x[i], &y[i]) != 2)
   chkexit ("No x or y in test!", JE);
  assert (x[i] >= -MaxC && x[i] <= MaxC);
  assert (y[i] >= -MaxC && y[i] <= MaxC);
 }
 chkend (fin, JE);
 rc = answer (fout, OK);
 fclose (fin);
 fclose (fout);
 if (!rc)
  chkexit ("Wrong convex hull!", WA);
 chkexit ("Right convex hull!", OK);
 return 0;
}
