#include <cassert>
#include <cmath>
#include <cstdio>
#include <cstdlib>
#include <cstring>

#define TASKNAME "double"

enum {OK, WA, PE, JE, NUM};
const char err [NUM] [4] = {"OK", "WA", "PE", "JE"};

FILE * fin, * fout, * fans;

void chkexit (const char * msg, int code)
{
 fprintf (stderr, "%s: %s\n", err[code], msg);
 exit (code);
}

void chkend (FILE * f, int mask)
{
 char ch;
 if (fscanf (f, " %c", &ch) == 1)
  chkexit ("Extra information given!", PE | mask);
}

const int MinN = 1, MaxN = 100000, Prime1 = 821, Prime2 = 262139;

char s [MaxN + 2], t [MaxN + 2];
int n, k;

bool answer (FILE * f, int mask)
{
 int i, ch1, ch2, ch3, ch4, p1, p2, count;

 if (fscanf (f, " %s", t) != 1)
  chkexit ("No substring given!", PE | mask);
 chkend (f, mask);

 if (!strcmp (t, "NONE")) return false;
 if (int (strlen (t)) != k)
  chkexit ("Wrong substring length!", WA | mask);
 ch1 = 0;
 ch2 = 0;
 for (i = 0; i < k; i++)
 {
  ch1 = ch1 * Prime1 + t[i];
  ch2 = ch2 * Prime2 + t[i];
 }
 ch3 = ch1;
 ch4 = ch2;

 count = 0;
 ch1 = 0;
 p1 = 1;
 ch2 = 0;
 p2 = 1;
 for (i = 0; i < k; i++)
 {
  ch1 = ch1 * Prime1 + s[i];
  p1 *= Prime1;
  ch2 = ch2 * Prime2 + s[i];
  p2 *= Prime2;
 }
 for (assert (i == k); i <= n; i++)
 {
  if (ch1 == ch3 && ch2 == ch4)
   count++;
  ch1 = ch1 * Prime1 + s[i] - p1 * s[i - k];
  ch2 = ch2 * Prime2 + s[i] - p2 * s[i - k];
 }
 if (count < 2)
  chkexit ("The given substring does not occur twice!", WA | mask);
 return true;
}

int main (int argc, char * argv [])
{
 bool rc, rj;
 assert (argc >= 4);
 if ((fin = fopen (argv[1], "r")) == NULL) chkexit ("No input file!", JE);
 if ((fout = fopen (argv[2], "r")) == NULL) chkexit ("No output file!", PE);
 if ((fans = fopen (argv[3], "r")) == NULL) chkexit ("No answer file!", JE);
 if (fscanf (fin, " %s", s) != 1)
  chkexit ("No S in test!", JE);
 n = strlen (s);
 if (fscanf (fin, " %d", &k) != 1)
  chkexit ("No k in test!", JE);
 chkend (fin, JE);
 assert (MinN <= k && k <= n && n <= MaxN);
 rc = answer (fout, OK);
 rj = answer (fans, JE);
 fclose (fin);
 fclose (fout);
 fclose (fans);
 if (rc && rj)
  chkexit ("Contestant and jury both found a valid substring!", OK);
 if (rc && !rj)
  chkexit ("Contestant found the substring but jury didn't!", JE);
 if (!rc && rj)
  chkexit ("Jury found the substring but contestant didn't!", WA);
 if (!rc && !rj)
  chkexit ("Contestant and jury agree there's no substring!", OK);
 assert (false);
 return 0;
}
